@@ -11,6 +11,8 @@ from rdarrays import recall
 from dependence import normal
 from dependence import cgauss
 from dependence import cstudent
+from dependence import cgumbel
+from dependence import cclayton
 
 from shrinkage import shrink
 from shrinkage import target_a
